# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class ItemDomainCatalogSearchResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'object_id': 'int',
        'object_name': 'str',
        'object_attribute_match_map': 'dict(str, str)',
        'catalog_item': 'ItemDomainCatalog',
        'inventory_list': 'list[ItemDomainInventory]',
        'display': 'str',
        'empty': 'bool'
    }

    attribute_map = {
        'object_id': 'objectId',
        'object_name': 'objectName',
        'object_attribute_match_map': 'objectAttributeMatchMap',
        'catalog_item': 'catalogItem',
        'inventory_list': 'inventoryList',
        'display': 'display',
        'empty': 'empty'
    }

    def __init__(self, object_id=None, object_name=None, object_attribute_match_map=None, catalog_item=None, inventory_list=None, display=None, empty=None, local_vars_configuration=None):  # noqa: E501
        """ItemDomainCatalogSearchResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._object_id = None
        self._object_name = None
        self._object_attribute_match_map = None
        self._catalog_item = None
        self._inventory_list = None
        self._display = None
        self._empty = None
        self.discriminator = None

        if object_id is not None:
            self.object_id = object_id
        if object_name is not None:
            self.object_name = object_name
        if object_attribute_match_map is not None:
            self.object_attribute_match_map = object_attribute_match_map
        if catalog_item is not None:
            self.catalog_item = catalog_item
        if inventory_list is not None:
            self.inventory_list = inventory_list
        if display is not None:
            self.display = display
        if empty is not None:
            self.empty = empty

    @property
    def object_id(self):
        """Gets the object_id of this ItemDomainCatalogSearchResult.  # noqa: E501


        :return: The object_id of this ItemDomainCatalogSearchResult.  # noqa: E501
        :rtype: int
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this ItemDomainCatalogSearchResult.


        :param object_id: The object_id of this ItemDomainCatalogSearchResult.  # noqa: E501
        :type: int
        """

        self._object_id = object_id

    @property
    def object_name(self):
        """Gets the object_name of this ItemDomainCatalogSearchResult.  # noqa: E501


        :return: The object_name of this ItemDomainCatalogSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """Sets the object_name of this ItemDomainCatalogSearchResult.


        :param object_name: The object_name of this ItemDomainCatalogSearchResult.  # noqa: E501
        :type: str
        """

        self._object_name = object_name

    @property
    def object_attribute_match_map(self):
        """Gets the object_attribute_match_map of this ItemDomainCatalogSearchResult.  # noqa: E501


        :return: The object_attribute_match_map of this ItemDomainCatalogSearchResult.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._object_attribute_match_map

    @object_attribute_match_map.setter
    def object_attribute_match_map(self, object_attribute_match_map):
        """Sets the object_attribute_match_map of this ItemDomainCatalogSearchResult.


        :param object_attribute_match_map: The object_attribute_match_map of this ItemDomainCatalogSearchResult.  # noqa: E501
        :type: dict(str, str)
        """

        self._object_attribute_match_map = object_attribute_match_map

    @property
    def catalog_item(self):
        """Gets the catalog_item of this ItemDomainCatalogSearchResult.  # noqa: E501


        :return: The catalog_item of this ItemDomainCatalogSearchResult.  # noqa: E501
        :rtype: ItemDomainCatalog
        """
        return self._catalog_item

    @catalog_item.setter
    def catalog_item(self, catalog_item):
        """Sets the catalog_item of this ItemDomainCatalogSearchResult.


        :param catalog_item: The catalog_item of this ItemDomainCatalogSearchResult.  # noqa: E501
        :type: ItemDomainCatalog
        """

        self._catalog_item = catalog_item

    @property
    def inventory_list(self):
        """Gets the inventory_list of this ItemDomainCatalogSearchResult.  # noqa: E501


        :return: The inventory_list of this ItemDomainCatalogSearchResult.  # noqa: E501
        :rtype: list[ItemDomainInventory]
        """
        return self._inventory_list

    @inventory_list.setter
    def inventory_list(self, inventory_list):
        """Sets the inventory_list of this ItemDomainCatalogSearchResult.


        :param inventory_list: The inventory_list of this ItemDomainCatalogSearchResult.  # noqa: E501
        :type: list[ItemDomainInventory]
        """

        self._inventory_list = inventory_list

    @property
    def display(self):
        """Gets the display of this ItemDomainCatalogSearchResult.  # noqa: E501


        :return: The display of this ItemDomainCatalogSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._display

    @display.setter
    def display(self, display):
        """Sets the display of this ItemDomainCatalogSearchResult.


        :param display: The display of this ItemDomainCatalogSearchResult.  # noqa: E501
        :type: str
        """

        self._display = display

    @property
    def empty(self):
        """Gets the empty of this ItemDomainCatalogSearchResult.  # noqa: E501


        :return: The empty of this ItemDomainCatalogSearchResult.  # noqa: E501
        :rtype: bool
        """
        return self._empty

    @empty.setter
    def empty(self, empty):
        """Sets the empty of this ItemDomainCatalogSearchResult.


        :param empty: The empty of this ItemDomainCatalogSearchResult.  # noqa: E501
        :type: bool
        """

        self._empty = empty

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemDomainCatalogSearchResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemDomainCatalogSearchResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class ItemDomainInventoryAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'tag': 'str',
        'catalog_item': 'ItemDomainCatalog',
        'serial_number': 'str'
    }

    attribute_map = {
        'tag': 'tag',
        'catalog_item': 'catalogItem',
        'serial_number': 'serialNumber'
    }

    def __init__(self, tag=None, catalog_item=None, serial_number=None, local_vars_configuration=None):  # noqa: E501
        """ItemDomainInventoryAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._tag = None
        self._catalog_item = None
        self._serial_number = None
        self.discriminator = None

        if tag is not None:
            self.tag = tag
        if catalog_item is not None:
            self.catalog_item = catalog_item
        if serial_number is not None:
            self.serial_number = serial_number

    @property
    def tag(self):
        """Gets the tag of this ItemDomainInventoryAllOf.  # noqa: E501


        :return: The tag of this ItemDomainInventoryAllOf.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this ItemDomainInventoryAllOf.


        :param tag: The tag of this ItemDomainInventoryAllOf.  # noqa: E501
        :type: str
        """

        self._tag = tag

    @property
    def catalog_item(self):
        """Gets the catalog_item of this ItemDomainInventoryAllOf.  # noqa: E501


        :return: The catalog_item of this ItemDomainInventoryAllOf.  # noqa: E501
        :rtype: ItemDomainCatalog
        """
        return self._catalog_item

    @catalog_item.setter
    def catalog_item(self, catalog_item):
        """Sets the catalog_item of this ItemDomainInventoryAllOf.


        :param catalog_item: The catalog_item of this ItemDomainInventoryAllOf.  # noqa: E501
        :type: ItemDomainCatalog
        """

        self._catalog_item = catalog_item

    @property
    def serial_number(self):
        """Gets the serial_number of this ItemDomainInventoryAllOf.  # noqa: E501


        :return: The serial_number of this ItemDomainInventoryAllOf.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this ItemDomainInventoryAllOf.


        :param serial_number: The serial_number of this ItemDomainInventoryAllOf.  # noqa: E501
        :type: str
        """

        self._serial_number = serial_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemDomainInventoryAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemDomainInventoryAllOf):
            return True

        return self.to_dict() != other.to_dict()



#!/usr/bin/env python

import os
from configparser import ConfigParser


class ConfigurationManager:
    CDB_INSTALL_DIR_ENV_NAME = 'CDB_INSTALL_DIR'
    CDB_PROD_CONFIG_SUBDIR = '%s/etc/cdb.conf'
    CONFIG_WEB_PORTAL_SECTION_NAME = 'WebPortal'
    CONFIG_PORTAL_VALUE_NAME = 'portalWebAddress'

    SESSION_COOKIE_FILE_PATH = '~/.cdb/api_session'

    # Singleton.
    __instance = None

    @classmethod
    def get_instance(cls):
        """ Get configuration manager singleton instance. """
        try:
            cm = ConfigurationManager()
        except ConfigurationManager as ex:
            cm = ex
        return cm

    def __init__(self):
        if ConfigurationManager.__instance:
            raise ConfigurationManager.__instance
        ConfigurationManager.__instance = self

        install_path = os.environ[self.CDB_INSTALL_DIR_ENV_NAME]
        configuration_file_path = self.CDB_PROD_CONFIG_SUBDIR % install_path

        self.configuration = ConfigParser()
        self.configuration.read(configuration_file_path)

    def get_portal_address(self):
        web_portal_section = self.configuration[self.CONFIG_WEB_PORTAL_SECTION_NAME]
        return web_portal_section[self.CONFIG_PORTAL_VALUE_NAME]

    def get_session_file_path(self):
        return os.path.expanduser(self.SESSION_COOKIE_FILE_PATH)



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class Domain(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'description': 'str',
        'item_identifier1_label': 'str',
        'item_identifier2_label': 'str',
        'item_type_label': 'str',
        'item_category_label': 'str',
        'item_list': 'list[Item]',
        'property_type_list': 'list[PropertyType]',
        'item_type_list': 'list[ItemType]',
        'item_category_list': 'list[ItemCategory]',
        'allowed_entity_type_list': 'list[EntityType]',
        'domain_rep_icon': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'item_identifier1_label': 'itemIdentifier1Label',
        'item_identifier2_label': 'itemIdentifier2Label',
        'item_type_label': 'itemTypeLabel',
        'item_category_label': 'itemCategoryLabel',
        'item_list': 'itemList',
        'property_type_list': 'propertyTypeList',
        'item_type_list': 'itemTypeList',
        'item_category_list': 'itemCategoryList',
        'allowed_entity_type_list': 'allowedEntityTypeList',
        'domain_rep_icon': 'domainRepIcon'
    }

    def __init__(self, id=None, name=None, description=None, item_identifier1_label=None, item_identifier2_label=None, item_type_label=None, item_category_label=None, item_list=None, property_type_list=None, item_type_list=None, item_category_list=None, allowed_entity_type_list=None, domain_rep_icon=None, local_vars_configuration=None):  # noqa: E501
        """Domain - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._description = None
        self._item_identifier1_label = None
        self._item_identifier2_label = None
        self._item_type_label = None
        self._item_category_label = None
        self._item_list = None
        self._property_type_list = None
        self._item_type_list = None
        self._item_category_list = None
        self._allowed_entity_type_list = None
        self._domain_rep_icon = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        if description is not None:
            self.description = description
        if item_identifier1_label is not None:
            self.item_identifier1_label = item_identifier1_label
        if item_identifier2_label is not None:
            self.item_identifier2_label = item_identifier2_label
        if item_type_label is not None:
            self.item_type_label = item_type_label
        if item_category_label is not None:
            self.item_category_label = item_category_label
        if item_list is not None:
            self.item_list = item_list
        if property_type_list is not None:
            self.property_type_list = property_type_list
        if item_type_list is not None:
            self.item_type_list = item_type_list
        if item_category_list is not None:
            self.item_category_list = item_category_list
        if allowed_entity_type_list is not None:
            self.allowed_entity_type_list = allowed_entity_type_list
        if domain_rep_icon is not None:
            self.domain_rep_icon = domain_rep_icon

    @property
    def id(self):
        """Gets the id of this Domain.  # noqa: E501


        :return: The id of this Domain.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Domain.


        :param id: The id of this Domain.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Domain.  # noqa: E501


        :return: The name of this Domain.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Domain.


        :param name: The name of this Domain.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 64):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this Domain.  # noqa: E501


        :return: The description of this Domain.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Domain.


        :param description: The description of this Domain.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 256):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def item_identifier1_label(self):
        """Gets the item_identifier1_label of this Domain.  # noqa: E501


        :return: The item_identifier1_label of this Domain.  # noqa: E501
        :rtype: str
        """
        return self._item_identifier1_label

    @item_identifier1_label.setter
    def item_identifier1_label(self, item_identifier1_label):
        """Sets the item_identifier1_label of this Domain.


        :param item_identifier1_label: The item_identifier1_label of this Domain.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                item_identifier1_label is not None and len(item_identifier1_label) > 32):
            raise ValueError("Invalid value for `item_identifier1_label`, length must be less than or equal to `32`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                item_identifier1_label is not None and len(item_identifier1_label) < 0):
            raise ValueError("Invalid value for `item_identifier1_label`, length must be greater than or equal to `0`")  # noqa: E501

        self._item_identifier1_label = item_identifier1_label

    @property
    def item_identifier2_label(self):
        """Gets the item_identifier2_label of this Domain.  # noqa: E501


        :return: The item_identifier2_label of this Domain.  # noqa: E501
        :rtype: str
        """
        return self._item_identifier2_label

    @item_identifier2_label.setter
    def item_identifier2_label(self, item_identifier2_label):
        """Sets the item_identifier2_label of this Domain.


        :param item_identifier2_label: The item_identifier2_label of this Domain.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                item_identifier2_label is not None and len(item_identifier2_label) > 32):
            raise ValueError("Invalid value for `item_identifier2_label`, length must be less than or equal to `32`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                item_identifier2_label is not None and len(item_identifier2_label) < 0):
            raise ValueError("Invalid value for `item_identifier2_label`, length must be greater than or equal to `0`")  # noqa: E501

        self._item_identifier2_label = item_identifier2_label

    @property
    def item_type_label(self):
        """Gets the item_type_label of this Domain.  # noqa: E501


        :return: The item_type_label of this Domain.  # noqa: E501
        :rtype: str
        """
        return self._item_type_label

    @item_type_label.setter
    def item_type_label(self, item_type_label):
        """Sets the item_type_label of this Domain.


        :param item_type_label: The item_type_label of this Domain.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                item_type_label is not None and len(item_type_label) > 32):
            raise ValueError("Invalid value for `item_type_label`, length must be less than or equal to `32`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                item_type_label is not None and len(item_type_label) < 0):
            raise ValueError("Invalid value for `item_type_label`, length must be greater than or equal to `0`")  # noqa: E501

        self._item_type_label = item_type_label

    @property
    def item_category_label(self):
        """Gets the item_category_label of this Domain.  # noqa: E501


        :return: The item_category_label of this Domain.  # noqa: E501
        :rtype: str
        """
        return self._item_category_label

    @item_category_label.setter
    def item_category_label(self, item_category_label):
        """Sets the item_category_label of this Domain.


        :param item_category_label: The item_category_label of this Domain.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                item_category_label is not None and len(item_category_label) > 32):
            raise ValueError("Invalid value for `item_category_label`, length must be less than or equal to `32`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                item_category_label is not None and len(item_category_label) < 0):
            raise ValueError("Invalid value for `item_category_label`, length must be greater than or equal to `0`")  # noqa: E501

        self._item_category_label = item_category_label

    @property
    def item_list(self):
        """Gets the item_list of this Domain.  # noqa: E501


        :return: The item_list of this Domain.  # noqa: E501
        :rtype: list[Item]
        """
        return self._item_list

    @item_list.setter
    def item_list(self, item_list):
        """Sets the item_list of this Domain.


        :param item_list: The item_list of this Domain.  # noqa: E501
        :type: list[Item]
        """

        self._item_list = item_list

    @property
    def property_type_list(self):
        """Gets the property_type_list of this Domain.  # noqa: E501


        :return: The property_type_list of this Domain.  # noqa: E501
        :rtype: list[PropertyType]
        """
        return self._property_type_list

    @property_type_list.setter
    def property_type_list(self, property_type_list):
        """Sets the property_type_list of this Domain.


        :param property_type_list: The property_type_list of this Domain.  # noqa: E501
        :type: list[PropertyType]
        """

        self._property_type_list = property_type_list

    @property
    def item_type_list(self):
        """Gets the item_type_list of this Domain.  # noqa: E501


        :return: The item_type_list of this Domain.  # noqa: E501
        :rtype: list[ItemType]
        """
        return self._item_type_list

    @item_type_list.setter
    def item_type_list(self, item_type_list):
        """Sets the item_type_list of this Domain.


        :param item_type_list: The item_type_list of this Domain.  # noqa: E501
        :type: list[ItemType]
        """

        self._item_type_list = item_type_list

    @property
    def item_category_list(self):
        """Gets the item_category_list of this Domain.  # noqa: E501


        :return: The item_category_list of this Domain.  # noqa: E501
        :rtype: list[ItemCategory]
        """
        return self._item_category_list

    @item_category_list.setter
    def item_category_list(self, item_category_list):
        """Sets the item_category_list of this Domain.


        :param item_category_list: The item_category_list of this Domain.  # noqa: E501
        :type: list[ItemCategory]
        """

        self._item_category_list = item_category_list

    @property
    def allowed_entity_type_list(self):
        """Gets the allowed_entity_type_list of this Domain.  # noqa: E501


        :return: The allowed_entity_type_list of this Domain.  # noqa: E501
        :rtype: list[EntityType]
        """
        return self._allowed_entity_type_list

    @allowed_entity_type_list.setter
    def allowed_entity_type_list(self, allowed_entity_type_list):
        """Sets the allowed_entity_type_list of this Domain.


        :param allowed_entity_type_list: The allowed_entity_type_list of this Domain.  # noqa: E501
        :type: list[EntityType]
        """

        self._allowed_entity_type_list = allowed_entity_type_list

    @property
    def domain_rep_icon(self):
        """Gets the domain_rep_icon of this Domain.  # noqa: E501


        :return: The domain_rep_icon of this Domain.  # noqa: E501
        :rtype: str
        """
        return self._domain_rep_icon

    @domain_rep_icon.setter
    def domain_rep_icon(self, domain_rep_icon):
        """Sets the domain_rep_icon of this Domain.


        :param domain_rep_icon: The domain_rep_icon of this Domain.  # noqa: E501
        :type: str
        """

        self._domain_rep_icon = domain_rep_icon

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Domain):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Domain):
            return True

        return self.to_dict() != other.to_dict()
